@@ -1,9 +1,9 @@
 from django.db.models import Manager
 from django.core.exceptions import ObjectDoesNotExist
 from rest_framework import status
-from rest_framework.authtoken.models import Token
 from rest_framework.reverse import reverse
 from rest_framework.test import APITestCase
+from six import text_type
 
 
 class BaseRESTAPITestCase(APITestCase):
@@ -20,13 +20,11 @@ class BaseRESTAPITestCase(APITestCase):
     DETAIL_SUFFIX = '-detail'
     #: The field to use for DB and route lookups. Defaults to ``'pk'``.
     lookup_field = 'pk'
-    #: User factory to use in case you need to login for auth/permissions testing. Defaults to ``None``.
+    #: User factory to use in case you need user authentication for testing. Defaults to ``None``.
     user_factory = None
-    #: Whether to use token authentication instead of session. Defaults to ``False``.
-    use_token_auth = False
     #: The main test subject.
     object = None
-    #: The user instance created if the ``user_factory`` is set and used. Defaults to ``False``.
+    #: The user instance created if the ``user_factory`` is set and used. Defaults to ``None``.
     user = None
 
     def get_factory_class(self):
@@ -51,47 +49,19 @@ class BaseRESTAPITestCase(APITestCase):
 
         return factory.create()
 
-    def get_credentials(self, user):
-        """Return the credentials dictionary.
-
-        By default this consists getting the ``username`` field of the ``user`` instance
-        and the ``raw_password`` attribute of the ``user_factory`` attribute of this class.
-
-        :param user: The user instance that will be used to login.
-        :returns: A dictionary of credentials for user login.
-
-        .. admonition:: example
-
-            .. code:: python
-
-                {'username': 'ydaniv'
-                 'password': 'bellbottoms'}
-
-        .. note: This method assumes you set the user's password in plain text in ``user_factory.raw_password``.
-        """
-
-        return {
-            'username': user.get_username(),
-            'password': self.user_factory.raw_password}
-
     def setUp(self):
         """Generates the main object and user instance if needed.
 
-        | The user will also be logged in automatically, using the ``login()`` method of the test's client.
-        | You can opt for token authentication by setting the class' ``use_token_auth`` to ``True``.
-
         The user instance will be created only if the ``user_factory`` attribute is set to the factory class.
+
+        If there is an available user instance, that user will be force authenticated.
         """
 
-        # create a user and log in to get permissions
+        # create and force authenticate user
         user_factory = getattr(self, 'user_factory')
         if user_factory:
             self.user = user_factory.create()
-            if self.use_token_auth:
-                token = Token.objects.get(user=self.user)
-                self.client.credentials(HTTP_AUTHORIZATION='Token ' + token.key)
-            else:
-                self.client.login(**self.get_credentials(self.user))
+            self.client.force_authenticate(self.user)
 
         # create the object
         self.object = self.get_object(self.get_factory_class())
@@ -142,10 +112,7 @@ class ListAPITestCaseMixin(object):
 
         response = self.get_list_response(**kwargs)
 
-        if response.status_code != status.HTTP_200_OK:
-            print '\n%s' % response.data
-
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_200_OK, response.data)
         self.assertIn('results', response.data)
 
         return response
@@ -167,7 +134,7 @@ class DetailAPITestCaseMixin(object):
         """
 
         object_id = getattr(self.object, self.lookup_field)
-        return reverse(self.base_name + self.DETAIL_SUFFIX, args=[unicode(object_id)])
+        return reverse(self.base_name + self.DETAIL_SUFFIX, args=[text_type(object_id)])
 
     def get_detail_response(self, **kwargs):
         """Send the detail request and return the response.
@@ -213,10 +180,7 @@ class DetailAPITestCaseMixin(object):
 
         response = self.get_detail_response(**kwargs)
 
-        if response.status_code != status.HTTP_200_OK:
-            print '\n%s' % response.data
-
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_200_OK, response.data)
         self._check_attributes(response.data)
 
         return response
@@ -227,9 +191,9 @@ class DetailAPITestCaseMixin(object):
                 value = attr[1](self.object)
                 attr = attr[0]
             else:
-                value = unicode(getattr(self.object, attr))
+                value = text_type(getattr(self.object, attr))
 
-            self.assertEqual(value, data[attr])
+            self.assertEqual(value, text_type(data[attr]))
 
 
 class CreateAPITestCaseMixin(object):
@@ -282,10 +246,7 @@ class CreateAPITestCaseMixin(object):
 
         response = self.get_create_response(data, **kwargs)
 
-        if response.status_code != status.HTTP_201_CREATED:
-            print '\n%s' % response.data
-
-        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
+        self.assertEqual(response.status_code, status.HTTP_201_CREATED, response.data)
 
         # another sanity check:
         # getting the instance from database simply to see that it's found and does not raise any exception
@@ -336,7 +297,7 @@ class DestroyAPITestCaseMixin(object):
 
         response = self.get_destroy_response(**kwargs)
 
-        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT)
+        self.assertEqual(response.status_code, status.HTTP_204_NO_CONTENT, response.data)
         # Another sanity check:
         # see that the instance is removed from the database.
         self.assertRaises(ObjectDoesNotExist, self.object.__class__.objects.get, **{self.lookup_field: self.object_id})
@@ -431,10 +392,7 @@ class UpdateAPITestCaseMixin(object):
 
         response = self.get_update_response(data, results, use_patch, **kwargs)
 
-        if response.status_code == status.HTTP_400_BAD_REQUEST:
-            print '\n%s' % response.data
-
-        self.assertEqual(response.status_code, status.HTTP_200_OK)
+        self.assertEqual(response.status_code, status.HTTP_200_OK, response.data)
 
         # getting a fresh copy of the object from DB
         updated = self.object.__class__.objects.get(**{self.lookup_field: self.object_id})
@@ -466,15 +424,15 @@ class UpdateAPITestCaseMixin(object):
                 # hack to check if there's a uuid field and use it instead of pk
                 # because of the issue with setting it as primary for Accounts
                 if hasattr(related, 'uuid'):
-                    attribute = unicode(related.uuid)
+                    attribute = text_type(related.uuid)
                 else:
-                    attribute = unicode(related.pk)
+                    attribute = text_type(related.pk)
             else:
                 attribute = getattr(obj, key)
                 # Handle case of a ManyToMany relation
                 if isinstance(attribute, Manager):
                     for pk in value:
-                        self.assertIn(pk, [unicode(item.pk) for item in attribute.all()])
+                        self.assertIn(pk, [text_type(item.pk) for item in attribute.all()])
                     return True
 
             self.assertEqual(attribute, results.get(key, value))
